<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 * @return array An array of default values
 */

function travel_ultimate_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$travel_ultimate_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#29a0eb',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		
		// typography Options
		'theme_typography' 				=> '',
		'body_theme_typography' 		=> '',
		'theme_section_title_typography' 		=> '',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'wp_travel_sidebar_position'    => 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'excerpt_text'           => esc_html__( 'Tour Details', 'travel-ultimate-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html( 'Copyright &copy; %1$s %2$s by %3$s', 'travel-ultimate-pro' ), '[the-year]', esc_html( $theme_data->get( 'Name') ), '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>' ),
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Slider,Search,Package,About Us,CTA,Guide,Destination,Testimonial,Event,Counter',

		'default_sortable'              => 'slider,search,package,about,cta,guide,destination,testimonial,event,counter',

		'second_sortable'               => 'slider,service,about,counter,team,subscription,testimonial,event',

		'third_sortable'                => 'slider,service,about,reason,event',

		'fourth_sortable'               => 'slider,service,masonry,product,featured,latest_product,event',

		'fifth_sortable'                => 'featured_posts,main_content,sports_news,latest_posts,event',

		'sixth_sortable'                => 'slider,service,cta,about,counter,team,subscription,testimonial,event',

		'seventh_sortable'              => 'slider,featured_posts,event,latest_posts',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'travel-ultimate-pro' ),
		'hide_date' 					=> false,
		// 'hide_category'					=> false,
		// 'hide_author'					=> false,
		'archive_column'				=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */
		
		//homepage layot
		'home_layout'					=> 'default-design',

		// Top bar
		'top_section_enable'			=> true,
		'top_contact_info'					=> __( 'Any Questions? Call Us: <a href="#">1-223-355-2214</a>', 'travel-ultimate-pro' ),
		'search_section_enable'			=> true,

		// Banner
		'cta_section_enable'			=> true,
		'cta_content_type'			=> 'page',
		'cta_btn_label'				=> esc_html__( 'View All Details', 'travel-ultimate-pro' ),

		// package
		'package_section_enable'		=> true,
		'package_content_type'			=> 'category',
		'package_count'					=> 3,
		'package_column'				=> 'col-3',
		'package_btn_txt'				=> esc_html__( 'See all packages', 'travel-ultimate-pro' ),
		'package_btn_url'				=> '#',
		'package_title'					=> esc_html__( 'We are all here at your services for everything.', 'travel-ultimate-pro' ),
		'package_sub_title'					=> esc_html__( 'Recommended Packages', 'travel-ultimate-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'About Us', 'travel-ultimate-pro' ),
		'about_description'				=> sprintf( '%1$s <br> %2$s',  esc_html__( 'There is evidence that perceptions of beauty are evolutionary determined, that things, aspects of people and landscapes considered beautiful are typically found in situations likely to give enhanced survival of the perceiving human genes.', 'travel-ultimate-pro' ), esc_html__( 'They also include less tangible advantages such as a confidence (not always warranted) that the system will be forgiving of your and your children mistakes, that your bad habits will not be seen as racial flaws, that portrayals of your race in the media and in history books will be mostly positive.', 'travel-ultimate-pro' ) ),
		'about_sub_title'				=> esc_html__( 'About Us', 'travel-ultimate-pro' ),
		'about_button'				=> esc_html__( 'Read More', 'travel-ultimate-pro' ),
		'tour_content_type'			=> 'cat',
		'tour_count'			=> 7,

		// Slider
		'slider_section_enable'			=> true,
		'slider_count'					=> 3,
		'slider_content_type'			=> 'category',

		// guide
		'guide_section_enable'			=> true,
		'guide_count'					=> 4,
		'guide_content_type'			=> 'category',
		'guide_title'					=> esc_html__( 'Survival Guide', 'travel-ultimate-pro' ),
		'guide_subtitle'				=> esc_html__( 'Prepare Yourself', 'travel-ultimate-pro' ),

		// destination
		'destination_section_enable'			=> true,
		'destination_count'					=> 6,
		'destination_content_type'			=> 'category',
		'destination_title'					=> esc_html__( 'Great Tour Around World', 'travel-ultimate-pro' ),
		'destination_subtitle'				=> esc_html__( 'Find our most', 'travel-ultimate-pro' ),
		'destination_btn'					=> esc_html__( 'Book Now', 'travel-ultimate-pro' ),

		// event
		'event_section_enable'			=> true,
		'event_count'					=> 6,
		'event_content_type'			=> 'category',
		'event_title'					=> esc_html__( 'Event Calendar', 'travel-ultimate-pro' ),
		'event_subtitle'				=> esc_html__( 'Upcoming events', 'travel-ultimate-pro' ),
		'event_btn'					=> esc_html__( 'View All Posts', 'travel-ultimate-pro' ),
		'event_btn_url'					=> '#',

		// clients
		'client_section_enable'			=> true,
		'client_title'					=> esc_html__( 'We value our customer/clients above all others.', 'travel-ultimate-pro' ),
		'client_content_type'			=> 'category',
		'client_count'					=> 6,

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_title'					=> esc_html__( 'Elite Travellers say', 'travel-ultimate-pro' ),
		'testimonial_subtitle'				=> esc_html__( 'Find out what', 'travel-ultimate-pro' ),
		'testimonial_content_type'		=> 'category',
		'testimonial_column'			=> 3,
		'testimonial_count'				=> 3,
		'testimonial_short_description'	=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'travel-ultimate-pro' ),

		
		// Counter
		'counter_section_enable'		=> true,
		'counter_title'					=> esc_html__( 'Stats Counter', 'travel-ultimate-pro' ),
		'counter_subtitle'				=> esc_html__( 'Statistics', 'travel-ultimate-pro' ),

		//service
		'service_section_enable'		=> true,
		'service_title'					=> esc_html__( 'What We Do', 'travel-ultimate-pro' ),
		'service_description'			=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'travel-ultimate-pro' ),
		'service_count'					=> 3,
		'service_content_type'			=> 'category',

		//team
		'team_section_enable'			=> true,
		'team_title'					=> esc_html__( 'Meet Our Team', 'travel-ultimate-pro' ),
		'team_description'				=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'travel-ultimate-pro' ),
		'team_count'					=> 4,
		'team_content_type'				=> 'category',

		//subscription
		'subscription_section_enable'	=> true,
		'subscription_sub_title'		=> esc_html__( 'Newsletter', 'travel-ultimate-pro' ),
		'subscription_title'			=> esc_html__( 'Stay informed', 'travel-ultimate-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'travel-ultimate-pro' ),

		// Reason
		'reason_section_enable'			=> true,
		'reason_content_type'			=> 'page',
		'reason_title'					=> esc_html__( 'Analysis and Consulting', 'travel-ultimate-pro'),
		'reason_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit. Fusce sed cursus quam. Nam sit amet sapien eu lorem fringilla ullamcorper. Integer fermentum erat gravida, sagittis quam in, condimentum ligula.', 'travel-ultimate-pro' ),

		//masonry section
		'masonry_section_enable'		=> false,	

		// Product
		'product_section_enable'		=> false,
		'product_content_type'			=> 'product-category',
		'product_count'					=> 4,
		'product_title'					=> esc_html__( 'Popular Products', 'travel-ultimate-pro' ),
		'product_subtitle'				=> esc_html__( 'Latest spring collection for fashionable person like you.', 'travel-ultimate-pro' ),

		//latest Product
		'latest_product_section_enable'		=> false,
		'latest_product_content_type'			=> 'product-category',
		'latest_product_count'					=> 4,
		'latest_product_title'					=> esc_html__( 'NEW ARRIVALS', 'travel-ultimate-pro' ),
		'latest_product_subtitle'				=> esc_html__( 'All Styles in This Spring', 'travel-ultimate-pro' ),

		//featured section
		'featured_section_enable'		=> false,

		// Featured Posts
		'featured_posts_section_enable'		=> true,
		'featured_post_title'				=> esc_html__( 'Featured Posts', 'travel-ultimate-pro' ),
		'featured_posts_count'				=> 3,
		'featured_posts_content_type'		=> 'category',

		// popular Posts
		'popular_posts_section_enable'		=> true,
		'popular_title'						=> esc_html__( 'POPULAR POSTS', 'travel-ultimate-pro' ),
		'popular_posts_count'				=> 4,
		'popular_posts_content_type'		=> 'category',

		// recent
		'recent_section_enable'			=> true,
		'recent_title'					=> esc_html__( 'RECENT POSTS', 'travel-ultimate-pro' ),
		'recent_content_type'			=> 'category',
		'recent_count'					=> 6,

		// sports_news
		'sports_news_section_enable'		=> true,
		'sports_news_title'					=> esc_html__( 'SPORTS NEWS', 'travel-ultimate-pro' ),
		'sports_news_content_type'			=> 'category',
		'sports_news_count'					=> 4,

		// latest_posts
		'latest_posts_section_enable'		=> true,
		'latest_posts_title'				=> esc_html__( 'Latest Posts', 'travel-ultimate-pro' ),
		'latest_posts_content_type'			=> 'category',
		'latest_posts_count'				=> 3,
		'latest_posts_button'				=> esc_html__( 'CONTINUE READING', 'travel-ultimate-pro' ),
	
		
	);

	$output = apply_filters( 'travel_ultimate_pro_default_theme_options', $travel_ultimate_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}