<?php
/**
 * Featured Posts Section options
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */

// Add Featured Posts section
$wp_customize->add_section( 'travel_ultimate_pro_featured_posts_section', array(
	'title'             => esc_html__( 'Featured Posts','travel-ultimate-pro' ),
	'description'       => esc_html__( 'Featured Posts Section options.', 'travel-ultimate-pro' ),
	'panel'             => 'travel_ultimate_pro_front_page_panel',
) );

// Featured Posts content enable control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[featured_posts_section_enable]', array(
	'default'			=> 	$options['featured_posts_section_enable'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Ultimate_Pro_Switch_Control( $wp_customize, 'travel_ultimate_pro_theme_options[featured_posts_section_enable]', array(
	'label'             => esc_html__( 'Featured Posts Section Enable', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_featured_posts_section',
	'on_off_label' 		=> travel_ultimate_pro_switch_options(),
) ) );

if ( $options['home_layout'] == 'seventh-design' ):

// featured_post title setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[featured_post_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_post_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[featured_post_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_featured_posts_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_featured_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[featured_post_title]', array(
		'selector'            => '#blog-featured-posts h2.section-title',
		'settings'            => 'travel_ultimate_pro_theme_options[featured_post_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_featured_post_title_partial',
    ) );
}

endif;

// Event social icons number control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[featured_posts_count]', array(
	'default'          	=> $options['featured_posts_count'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[featured_posts_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_featured_posts_section',
	'active_callback'   => 'travel_ultimate_pro_is_featured_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'style' => 'width: 100px;'
		),
) );

// Featured Posts content type control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[featured_posts_content_type]', array(
	'default'          	=> $options['featured_posts_content_type'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[featured_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_featured_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_ultimate_pro_is_featured_posts_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travel-ultimate-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-ultimate-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-ultimate-pro' ),
	),
) );

for ( $i = 1; $i <= $options['featured_posts_count']; $i++ ) :
	// featured_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_featured_posts_section',
		'choices'			=> travel_ultimate_pro_page_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_featured_posts_section_content_page_enable',
	) ) );

	// featured_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_featured_posts_section',
		'choices'			=> travel_ultimate_pro_post_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_featured_posts_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[featured_posts_content_category]', array(
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[featured_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-ultimate-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_featured_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_ultimate_pro_is_featured_posts_section_content_category_enable'
) ) );