<?php
/**
* Slider Section options
*
* @package Theme Palace
* @subpackage Travel Ultimate Pro
* @since Travel Ultimate Pro 1.0.0
*/

// Add Slider section
$wp_customize->add_section( 'travel_ultimate_pro_slider_section', array(
	'title'             => esc_html__( 'Slider','travel-ultimate-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'travel-ultimate-pro' ),
	'panel'             => 'travel_ultimate_pro_front_page_panel',
	) );

// Slider content enable control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Travel_Ultimate_Pro_Switch_Control( $wp_customize, 'travel_ultimate_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_slider_section',
	'on_off_label' 		=> travel_ultimate_pro_switch_options(),
	) ) );

// slider number control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_number_range',
	) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_slider_section',
	'active_callback'   => 'travel_ultimate_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'style' => 'width: 100px;'
		),
	) );

// Slider content type control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_select',
	) );

$choices = array( 
	'page' 		=> esc_html__( 'Page', 'travel-ultimate-pro' ),
	'post' 		=> esc_html__( 'Post', 'travel-ultimate-pro' ),
	'category' 	=> esc_html__( 'Category', 'travel-ultimate-pro' ),
	);
/*if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'travel-ultimate-pro' );
}*/
$wp_customize->add_control( 'travel_ultimate_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_ultimate_pro_is_slider_section_enable',
	'choices'			=> travel_ultimate_pro_slider_content_type(),
	) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
		) );

$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[slider_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-ultimate-pro' ), $i ),
	'section'           => 'travel_ultimate_pro_slider_section',
	'choices'			=> travel_ultimate_pro_page_choices(),
	'active_callback'	=> 'travel_ultimate_pro_is_slider_section_content_page_enable',
	) ) );

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
	) );

$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-ultimate-pro' ), $i ),
	'section'           => 'travel_ultimate_pro_slider_section',
	'choices'			=> travel_ultimate_pro_post_choices(),
	'active_callback'	=> 'travel_ultimate_pro_is_slider_section_content_post_enable',
	) ) );


if ( class_exists( 'WP_Travel' ) ) {
// slider trip drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'absint',
		) );

	$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Trip %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_slider_section',
		'choices'			=> travel_ultimate_pro_trip_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_slider_section_content_trip_enable',
		) ) );
}


	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_content_product_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
		) );

	$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[slider_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_slider_section',
		'choices'			=> travel_ultimate_pro_product_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_slider_section_content_product_enable',
		) ) );

if ( $options['home_layout'] == 'default-design' ):

// slider title setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_sub_title_' . $i . ']', array(
	'sanitize_callback' => 'sanitize_text_field',
	) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[slider_sub_title_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Sub title %d', 'travel-ultimate-pro' ), $i ),
	'section'        	=> 'travel_ultimate_pro_slider_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_slider_section_enable',
	'type'				=> 'text',
	) );

endif;

// slider read more setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_read_more_' . $i . ']', array(
	'sanitize_callback' => 'sanitize_text_field',
	) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[slider_read_more_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Read more %d', 'travel-ultimate-pro' ), $i ),
	'section'        	=> 'travel_ultimate_pro_slider_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_slider_section_enable',
	'type'				=> 'text',
	) );

// slider hr setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[slider_hr_'. $i .']', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Travel_Ultimate_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_ultimate_pro_theme_options[slider_hr_'. $i .']',
	array(
		'section'         => 'travel_ultimate_pro_slider_section',
		'active_callback' => 'travel_ultimate_pro_is_slider_section_enable',
		'type'			  => 'hr'
		) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-ultimate-pro' ),
	'description'      	=> esc_html__( 'Note: Slider selected no of posts will be shown from selected category', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_ultimate_pro_is_slider_section_content_category_enable'
	) ) );

	// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[slider_content_product_category]', array(
	'sanitize_callback' => 'absint',
	) ) ;

$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[slider_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'travel-ultimate-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_slider_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_ultimate_pro_is_slider_section_content_product_category_enable'
	) ) );
