<?php 

/**
* Sports News section
*
* This is the template for the content of about section
*
* @package Theme Palace
* @subpackage Travel Ultimate Pro
* @since Travel Ultimate Pro 1.0.0
*/

if ( ! function_exists( 'travel_ultimate_pro_add_sports_news_section' ) ) :
/**
* Add recent section
*
*@since Travel Ultimate Pro 1.0.0
*/
function travel_ultimate_pro_add_sports_news_section() {
    $options = travel_ultimate_pro_get_theme_options();
// Check if recent is enabled on frontpage
    $sports_news_enable = apply_filters( 'travel_ultimate_pro_section_status', true, 'sports_news_section_enable' );

    if ( true !== $sports_news_enable ) {
        return false;
    }
// Get recent section details
    $section_details = array();
    $section_details = apply_filters( 'travel_ultimate_pro_filter_sports_news_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render recent section now.
    travel_ultimate_pro_render_sports_news_section( $section_details );
}
endif;

if ( ! function_exists( 'travel_ultimate_pro_get_sports_news_section_details' ) ) :
/**
* recent section details.
*
* @since Travel Ultimate Pro 1.0.0
* @param array $input recent section details.
*/
function travel_ultimate_pro_get_sports_news_section_details( $input ) {
    $options = travel_ultimate_pro_get_theme_options();

// Content type.
    $sports_news_content_type  = $options['sports_news_content_type'];
    $sports_news_count = ! empty( $options['sports_news_count'] ) ? $options['sports_news_count'] : 4;

    $content = array();
    switch ( $sports_news_content_type ) {

        case 'page':
        $page_ids = array();

        for ( $i = 1; $i <= $sports_news_count; $i++ ) {
            if ( ! empty( $options['sports_news_content_page_' . $i] ) )
                $page_ids[] = $options['sports_news_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $sports_news_count ),
            'orderby'           => 'post__in',
            );                    
        break;

        case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $sports_news_count; $i++ ) {
            if ( ! empty( $options['sports_news_content_post_' . $i] ) )
                $post_ids[] = $options['sports_news_content_post_' . $i];
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $sports_news_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );                    
        break;

        case 'category':
        $cat_id = ! empty( $options['sports_news_content_category'] ) ? $options['sports_news_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $sports_news_count ),
            'cat'               => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
            );                    
        break;

        default:
        break;
    }

// Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['auth_id']   = get_the_author_meta('ID');
    $page_post['title']     = get_the_title();
    $page_post['url']       = get_the_permalink();
    $page_post['excerpt']   = travel_ultimate_pro_trim_content( 25 );
    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
    array_push( $content, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// recent section content details.
add_filter( 'travel_ultimate_pro_filter_sports_news_section_details', 'travel_ultimate_pro_get_sports_news_section_details' );

if ( ! function_exists( 'travel_ultimate_pro_render_sports_news_section' ) ) :
/**
* Start recent section
*
* @return string recent content
* @since Travel Ultimate Pro 1.0.0
*
*/
function travel_ultimate_pro_render_sports_news_section( $content_details = array() ) {
    $options = travel_ultimate_pro_get_theme_options();
    $sports_news_content_type  = $options['sports_news_content_type'];
    

    if ( empty( $content_details ) ) {
        return;
    } ?>

    <div id="magazine-sports-news" class="relative page-section">
        <div class="wrapper">
        <?php if( !empty( $options['sports_news_title'] ) ): ?>
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $options['sports_news_title'] ) ?></h2>
            </div><!-- .section-header -->
        <?php endif; ?>

            <div class="section-content col-4 clear">

            <?php foreach ($content_details as $content): ?>
                
                <article class="has-post-thumbnail">
                <?php if( !empty( $content['image'] ) ): ?>
                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                    </div><!-- .featured-image -->
                <?php endif; ?>

                    <div class="entry-container">
                    <?php if ( $sports_news_content_type !== 'page' ) : ?>
                        <div class="entry-meta">
                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ) ?>
                            </span>                            
                        </div><!-- .entry-meta -->
                    <?php endif; ?>

                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>

                        <div class="entry-meta author-posted-on">
                            <?php
                            echo travel_ultimate_pro_author( $content['auth_id'] ); 

                            travel_ultimate_pro_posted_on( $content['id'] );

                            ?>  
                        </div><!-- .entry-meta -->   

                        <div class="entry-content">
                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                        </div><!-- .entry-content -->
                    </div><!-- .entry-container -->
                </article>

            <?php endforeach; ?>

            </div><!-- .section-content -->
        </div><!-- .wrapper -->
    </div>

    <?php }
    endif;